import assert from "assert"

import {
    Clamp,
    Lerp,
    Unlerp
} from "../ts/lib/util/Vector"

describe("Clamp", () => {
    it("Should clamp a number between a min and max boundary.", () => {
        assert.strictEqual(Clamp(-5, -2, 5), -2);
        assert.strictEqual(Clamp(5, -5, 5), 5);
        assert.strictEqual(Clamp(-67, -100, -70), -70);
        assert.strictEqual(Clamp(Number.MAX_SAFE_INTEGER, -50, 50), 50);
    });
});

describe("Lerp", () => {
    it("Should map a floating point number between 0-1 to a number between a min and max boundary.", () => {
        assert.strictEqual(Lerp(0.5, -40, 40), 0);
        assert.strictEqual(Lerp(0.75, -40, 40), 20);
        assert.strictEqual(Lerp(0.25, -40, 40), -20);
    });
});

describe("Unlerp", () => {
    it("Should map a number between a min and max boundary to a floating point number between 0-1.", () => {
        assert.strictEqual(Unlerp(0, -40, 40), 0.5);
        assert.strictEqual(Unlerp(20, -40, 40), 0.75);
        assert.strictEqual(Unlerp(-20, -40, 40), 0.25);
    });
});